module  calc_project(
                        clk     ,
                        rst_n   ,
                        key_col ,
                        key_row ,
                        seg_sel ,
                        segment ,
                        beep    
                    );

    parameter   KEY_WID     =   4   ;
    parameter   STATE_WID   =   5   ;
    parameter   NUM_WID     =   27  ;
    parameter   SEG_NUM     =   8   ;
    parameter   SEG_WID     =   8   ;

    input                       clk         ;
    input                       rst_n       ;
    input   [KEY_WID-1:0]       key_col     ;
    output  [KEY_WID-1:0]       key_row     ;
    output  [SEG_NUM-1:0]       seg_sel     ;
    output  [SEG_WID-1:0]       segment     ;
    output                      beep        ;

    wire    [KEY_WID-1:0]       key_num     ;
    wire                        key_vld     ;
    wire    [KEY_WID-1:0]       key_num_out ;
    wire    [KEY_WID-1:0]       key_vld_out ;
    wire    [STATE_WID-1:0]     cal_state   ;
    wire    [NUM_WID-1:0]       op_1        ;
    wire                        op_1_err    ;
    wire    [KEY_WID-1:0]       oper        ;
    wire    [NUM_WID-1:0]       op_2        ;
    wire                        op_2_err    ;
    wire    [NUM_WID-1:0]       result      ;
    wire                        result_err  ;
    wire                        result_neg  ;   
    wire    [SEG_NUM*4-1:0]     display     ;
    wire                        display_vld ;

    key_scan   #(.TIME_20MS(100))key_scan_prj(
                            .clk        (clk)       ,
                            .rst_n      (rst_n)     ,
                            .key_col    (key_col)   ,
                            .key_row    (key_row)   ,
                            .key_num    (key_num)   ,
                            .key_vld    (key_vld)
                            );

    work_state  work_state_prj(
                                .clk        (clk        )   ,
                                .rst_n      (rst_n      )   ,
                                .key_num    (key_num    )   ,
                                .key_vld    (key_vld    )   ,
                                .result_err (result_err )   ,
                                .key_num_out(key_num_out)   ,
                                .key_vld_out(key_vld_out)   ,
                                .cal_state  (cal_state  )
                                );

    op_1    op_1_prj(
                        .clk        (clk        )   ,
                        .rst_n      (rst_n      )   ,
                        .key_num_out(key_num_out)   ,
                        .key_vld_out(key_vld_out)   ,
                        .cal_state  (cal_state  )   ,
                        .result     (result     )   ,
                        .op_1       (op_1       )   ,
                        .op_1_err   (op_1_err   )
                    );

    oper    oper_prj(
                        .clk        (clk        )   ,
                        .rst_n      (rst_n      )   ,
                        .key_num_out(key_num_out)   ,
                        .key_vld_out(key_vld_out)   ,
                        .cal_state  (cal_state  )   ,
                        .oper       (oper       )
                    );
    
    op_2    op_2_prj(
                        .clk        (clk        )   ,
                        .rst_n      (rst_n      )   ,
                        .key_num_out(key_num_out)   ,
                        .key_vld_out(key_vld_out)   ,
                        .cal_state  (cal_state  )   ,
                        .op_1       (op_1       )   ,
                        .op_2       (op_2       )   ,
                        .op_2_err   (op_2_err   )
                    );

    result  result_prj(
                        .clk        (clk        )   ,
                        .rst_n      (rst_n      )   ,
                        .key_num_out(key_num_out)   ,
                        .key_vld_out(key_vld_out)   ,
                        .cal_state  (cal_state  )   ,
                        .op_1       (op_1       )   ,
                        .oper       (oper       )   ,
                        .op_2       (op_2       )   ,
                        .result     (result     )   ,
                        .result_err (result_err )   ,
                        .result_neg (result_neg )
                    );

    display_sel  display_sel_prj(
                                .clk        (clk        )   ,
                                .rst_n      (rst_n      )   ,
                                .cal_state  (cal_state  )   ,
                                .op_1       (op_1       )   ,
                                .op_2       (op_2       )   ,
                                .result     (result     )   ,
                                .result_neg (result_neg )   ,
                                .display    (display    )   ,
                                .display_vld(display_vld)
                                );

    segment  segment_prj(
                            .rst_n      (rst_n      )   ,
                            .clk        (clk        )   ,
                            .display    (display    )   ,
                            .display_vld(display_vld)   ,
                            .seg_sel    (seg_sel    )   ,
                            .segment    (segment    )  
                        );
/*
    seg_disp    seg_disp_prj(
                                .clk(clk),
                                .rst_n(rst_n),
                                .din(display),
                                .din_vld(1'b1),
                                .seg_sel(seg_sel),
                                .segment(segment)
                            );
                            */
    beep    #(.CNT_1S(1))beep_prj(
                        .clk        (clk        )   ,
                        .rst_n      (rst_n      )   ,
                        .op_1_err   (op_1_err   )   ,
                        .op_2_err   (op_2_err   )   ,
                        .result_err (result_err )   ,
                        .beep       (beep       )
                    );

endmodule
                               
